@@ -140,7 +140,8 @@ class PageEditor(Page):
 
         form = self.request.form
         _ = self._
-        self.request.http_headers(self.request.nocache)
+        self.request.disableHttpCaching(level=2)
+        self.request.http_headers()
 
         raw_body = ''
         msg = None
@@ -304,6 +305,9 @@ Have a look at the diff of %(difflink)s to see what has been changed.""") % {
         # Send revision of the page our edit is based on
         self.request.write('<input type="hidden" name="rev" value="%d">' % (rev,))
 
+        # Create and send a ticket, so we can check the POST
+        self.request.write('<input type="hidden" name="ticket" value="%s">' % wikiutil.createTicket(self.request))
+
         # Save backto in a hidden input
         backto = form.get('backto', [None])[0]
         if backto:
@@ -366,7 +370,7 @@ If you don't want that, hit '''%(cancel_button_text)s''' to cancel your changes.
 
         self.request.write("<p>")
         self.request.write(_("Comment:"),
-            ' <input id="editor-comment" type="text" name="comment" value="%s" maxlength="80"'
+            ' <input id="editor-comment" type="text" name="comment" value="%s" maxlength="200"'
             ' onChange="flgChange = true;" onKeyPress="flgChange = true;">' % (
                 wikiutil.escape(kw.get('comment', ''), 1), ))
         self.request.write("</p>")
@@ -446,6 +450,57 @@ If you don't want that, hit '''%(cancel_button_text)s''' to cancel your changes.
         page = backto and Page(self.request, backto) or self
         page.send_page(self.request, msg=_('Edit was cancelled.'))
 
+    def renamePage(self, newpagename, comment=None):
+        """
+        Rename the current version of the page (making a backup before deletion
+        and keeping the backups, logs and attachments).
+        
+        @param comment: Comment given by user
+        @rtype: unicode
+        @return: success flag, error message
+        """
+        _ = self._
+        if not newpagename:
+            return False, _("You can't rename to an empty pagename.")
+
+        newpage = PageEditor(self.request, newpagename)
+
+        pageexists_error = _("""'''A page with the name {{{'%s'}}} already exists.'''
+
+Try a different name.""") % (newpagename,)
+
+        # Check whether a page with the new name already exists
+        if newpage.exists(includeDeleted=1):
+            return False, pageexists_error
+        
+        # Get old page text
+        savetext = self.get_raw_body()
+
+        oldpath = self.getPagePath(check_create=0)
+        newpath = newpage.getPagePath(check_create=0)
+
+        # Rename page
+
+        # NOTE: might fail if another process created newpagename just
+        # NOW, while you read this comment. Rename is atomic for files -
+        # but for directories, rename will fail if the directory
+        # exists. We should have global edit-lock to avoid this.
+        # See http://docs.python.org/lib/os-file-dir.html
+        try:
+            os.rename(oldpath, newpath)
+            self.error = None
+            # Save page text with a comment about the old name
+            savetext = u"## page was renamed from %s\n%s" % (self.page_name, savetext)
+            newpage.saveText(savetext, 0, comment=comment)
+            return True, None
+        except OSError, err:
+            # Try to understand what happened. Maybe its better to check
+            # the error code, but I just reused the available code above...
+            if newpage.exists(includeDeleted=1):
+                return False, pageexists_error
+            else:
+                return False, _('Could not rename page because of file system error: %s.') % unicode(err)
+
     def deletePage(self, comment=None):
         """
         Delete the current version of the page (making a backup before deletion
@@ -453,10 +508,10 @@ If you don't want that, hit '''%(cancel_button_text)s''' to cancel your changes.
         
         @param comment: Comment given by user
         @rtype: unicode
-        @return: error message
+        @return: success flag, error message
         """
         _ = self._
-        
+        success = True
         try:
             # First save a final backup copy of the current page
             # (recreating the page allows access to the backups again)
@@ -472,6 +527,7 @@ If you don't want that, hit '''%(cancel_button_text)s''' to cancel your changes.
                     raise err
         except self.SaveError, message:
             # XXX Error handling
+            success = False
             msg = "SaveError has occured in PageEditor.deletePage. We need locking there."
         
         # reset page object
@@ -495,7 +551,7 @@ If you don't want that, hit '''%(cancel_button_text)s''' to cancel your changes.
             key = formatter_name
             cache = caching.CacheEntry(self.request, arena, key)
             cache.remove()
-        return msg
+        return success, msg
 
     def _sendNotification(self, comment, emails, email_lang, revisions, trivial):
         """
@@ -510,12 +566,17 @@ If you don't want that, hit '''%(cancel_button_text)s''' to cancel your changes.
         """
         _ = lambda s, formatted=True, r=self.request, l=email_lang: r.getText(s, formatted=formatted, lang=l)
 
+        pagelink = self.request.getQualifiedURL(self.url(self.request))
+        if len(revisions) >= 2:
+            pagelink += "?action=diff&rev2=%i&rev1=%i" % tuple(revisions[:2])
+
+
         mailBody = _("Dear Wiki user,\n\n"
             'You have subscribed to a wiki page or wiki category on "%(sitename)s" for change notification.\n\n'
             "The following page has been changed by %(editor)s:\n"
             "%(pagelink)s\n\n", formatted=False) % {
                 'editor': self.uid_override or user.getUserIdentification(self.request),
-                'pagelink': self.request.getQualifiedURL(self.url(self.request)),
+                'pagelink': pagelink,
                 'sitename': self.cfg.sitename or self.request.getBaseURL(),
         }
 
@@ -747,14 +808,11 @@ If you don't want that, hit '''%(cancel_button_text)s''' to cancel your changes.
         
         if not os.path.exists(pagedir): # new page, create and init pagedir
             os.mkdir(pagedir)
-            os.chmod(pagedir, 0777 & config.umask)
         if not os.path.exists(revdir):        
             os.mkdir(revdir)
-            os.chmod(revdir, 0777 & config.umask)
             f = open(cfn, 'w')
             f.write('%08d\n' % 0)
             f.close()
-            os.chmod(cfn, 0666 & config.umask)
             
         got_lock = False
         retry = 0
@@ -794,7 +852,6 @@ If you don't want that, hit '''%(cancel_button_text)s''' to cancel your changes.
                 # Write the file using text/* mime type
                 f.write(self.encodeTextMimeType(text))
                 f.close()
-                os.chmod(pagefile, 0666 & config.umask)
                 mtime_usecs = wikiutil.timestamp2version(os.path.getmtime(pagefile))
                 # set in-memory content
                 self.set_raw_body(text)
@@ -858,13 +915,14 @@ If you don't want that, hit '''%(cancel_button_text)s''' to cancel your changes.
             # check if we already saved that page
             other = False
             pagelog = self.getPagePath('edit-log', use_underlay=0, isfile=1)
+            next_line = None
             for line in editlog.EditLog(self.request, pagelog).reverse():
                 if int(line.rev)==int(rev):
                     break
                 if not line.is_from_current_user(self.request):
                     other = True
                 next_line = line
-            if next_line.is_from_current_user(self.request):
+            if next_line and next_line.is_from_current_user(self.request):
                 saved_page = Page(self.request, self.page_name,
                                   rev=int(next_line.rev))
                 if newtext==saved_page.get_raw_body():
