@@ -41,7 +41,7 @@
 """
 
 import time, Cookie
-from MoinMoin import user
+from MoinMoin import config, user
 
 def log(request, **kw):
     """ just log the call, do nothing else """
@@ -171,8 +171,8 @@ def http(request, **kw):
     u = None
     # check if we are running Twisted
     if isinstance(request, RequestTwisted):
-        username = request.twistd.getUser()
-        password = request.twistd.getPassword()
+        username = request.twistd.getUser().decode(config.charset)
+        password = request.twistd.getPassword().decode(config.charset)
         # when using Twisted http auth, we use username and password from
         # the moin user profile, so both can be changed by user.
         u = user.User(request, auth_username=username, password=password,
@@ -182,7 +182,7 @@ def http(request, **kw):
         env = request.env
         auth_type = env.get('AUTH_TYPE','')
         if auth_type in ['Basic', 'Digest', 'NTLM', 'Negotiate',]:
-            username = env.get('REMOTE_USER','')
+            username = env.get('REMOTE_USER', '').decode(config.charset)
             if auth_type in ('NTLM', 'Negotiate',):
                 # converting to standard case so the user can even enter wrong case
                 # (added since windows does not distinguish between e.g.
@@ -222,9 +222,9 @@ def sslclientcert(request, **kw):
         if env.get('SSL_CLIENT_VERIFY', 'FAILURE') == 'SUCCESS':
             # if we only want to accept some specific CA, do a check like:
             # if env.get('SSL_CLIENT_I_DN_OU') == "http://www.cacert.org"
-            email = env.get('SSL_CLIENT_S_DN_Email', '')
+            email = env.get('SSL_CLIENT_S_DN_Email', '').decode(config.charset)
             email_lower = email.lower()
-            commonname = env.get('SSL_CLIENT_S_DN_CN', '')
+            commonname = env.get('SSL_CLIENT_S_DN_CN', '').decode(config.charset)
             commonname_lower = commonname.lower()
             if email_lower or commonname_lower:
                 for uid in user.getUserList(request):
@@ -320,6 +320,12 @@ def ldap_login(request, **kw):
         fetch some user infos from LDAP and create a user profile for that user that must
         be used by subsequent auth plugins (like moin_cookie) as we never return a user
         object from ldap_login.
+        python-ldap needs to be at least 2.0.0pre06 (available since mid 2002) for ldaps support -
+        some older debian installations (woody and older?) require libldap2-tls and python2.x-ldap-tls,
+        otherwise you get ldap.SERVER_DOWN: "Can't contact LDAP server" -
+        more recent debian installations have tls support in libldap2 (see dependency on gnutls)
+        and also in python-ldap.
+        use ldaps://server:636 url for ldaps, ldap://server for ldap with tls (plus some tls code, todo)
     """
     username = kw.get('name')
     password = kw.get('password')
@@ -329,81 +335,134 @@ def ldap_login(request, **kw):
 
     cfg = request.cfg
     verbose = cfg.ldap_verbose
-    
+
     if verbose: request.log("got name=%s login=%r logout=%r" % (username, login, logout))
-    
-    # we just intercept login and logout for ldap, other requests have to be
+
+    # we just intercept login for ldap, other requests have to be
     # handled by another auth handler
-    if not login and not logout:
+    if not login:
         return user_obj, True
-    
+
+    # we require non-empty password as ldap bind does a anon (not password
+    # protected) bind if the password is empty and SUCCEEDS!
+    if not password:
+        return None, False
+
     import sys, re
     import ldap
-    import traceback
 
-    u = None
-    coding = cfg.ldap_coding
     try:
-        if verbose: request.log("LDAP: Trying to initialize %s." % cfg.ldap_uri)
-        l = ldap.initialize(cfg.ldap_uri)
-        if verbose: request.log("LDAP: Connected to LDAP server %s." % cfg.ldap_uri)
-        # you can use %(username)s and %(password)s here to get the stuff entered in the form:
-        ldap_binddn = cfg.ldap_binddn % locals()
-        ldap_bindpw = cfg.ldap_bindpw % locals()
-        l.simple_bind_s(ldap_binddn.encode(coding), ldap_bindpw.encode(coding))
-        if verbose: request.log("LDAP: Bound with binddn %s" % ldap_binddn)
-
-        filterstr = "(%s=%s)" % (cfg.ldap_name_attribute, username)
-        if verbose: request.log("LDAP: Searching %s" % filterstr)
-        lusers = l.search_st(cfg.ldap_base, cfg.ldap_scope,
-                             filterstr.encode(coding), timeout=cfg.ldap_timeout)
-        result_length = len(lusers)
-        if result_length != 1:
-            if result_length > 1:
-                request.log("LDAP: Search found more than one (%d) matches for %s." % (len(lusers), filterstr))
-            if result_length == 0:
-                if verbose: request.log("LDAP: Search found no matches for %s." % (filterstr, ))
-            return user_obj, True
-
-        dn, ldap_dict = lusers[0]
-        if verbose:
-            request.log("LDAP: debug lusers = %r" % lusers)
-            for key,val in ldap_dict.items():
-                request.log("LDAP: %s: %s" % (key, val))
-
         try:
+            u = None
+            dn = None
+            coding = cfg.ldap_coding
+            if verbose: request.log("LDAP: Setting misc. options...")
+            ldap.set_option(ldap.OPT_PROTOCOL_VERSION, ldap.VERSION3) # ldap v2 is outdated
+            ldap.set_option(ldap.OPT_REFERRALS, 0) # needed for Active Directory:
+            ldap.set_option(ldap.OPT_NETWORK_TIMEOUT, cfg.ldap_timeout)
+
+            starttls = cfg.ldap_start_tls
+            if ldap.TLS_AVAIL:
+                for option, value in (
+                    (ldap.OPT_X_TLS_CACERTDIR, cfg.ldap_tls_cacertdir),
+                    (ldap.OPT_X_TLS_CACERTFILE, cfg.ldap_tls_cacertfile),
+                    (ldap.OPT_X_TLS_CERTFILE, cfg.ldap_tls_certfile),
+                    (ldap.OPT_X_TLS_KEYFILE, cfg.ldap_tls_keyfile),
+                    (ldap.OPT_X_TLS_REQUIRE_CERT, cfg.ldap_tls_require_cert), # ldap.OPT_X_TLS_NEVER - this is needed for self-signed ssl certs
+                    (ldap.OPT_X_TLS, starttls),
+                    #(ldap.OPT_X_TLS_ALLOW, 1),
+                ):
+                    if value:
+                        ldap.set_option(option, value)
+
+            server = cfg.ldap_uri
+            if verbose: request.log("LDAP: Trying to initialize %s." % server)
+            l = ldap.initialize(server)
+            if verbose: request.log("LDAP: Connected to LDAP server %s." % server)
+
+            if starttls and server.startswith('ldap:'):
+                if verbose: request.log("LDAP: Trying to start TLS to %s." % server)
+                try:
+                    l.start_tls_s()
+                    if verbose: request.log("LDAP: Using TLS to %s." % server)
+                except (ldap.SERVER_DOWN, ldap.CONNECT_ERROR), err:
+                    if verbose: request.log("LDAP: Couldn't establish TLS to %s (err: %s)." % (server, str(err)))
+                    raise
+
+            # you can use %(username)s and %(password)s here to get the stuff entered in the form:
+            ldap_binddn = cfg.ldap_binddn % locals()
+            ldap_bindpw = cfg.ldap_bindpw % locals()
+            l.simple_bind_s(ldap_binddn.encode(coding), ldap_bindpw.encode(coding))
+            if verbose: request.log("LDAP: Bound with binddn %s" % ldap_binddn)
+
+            # you can use %(username)s here to get the stuff entered in the form:
+            filterstr = cfg.ldap_filter % locals()
+            if verbose: request.log("LDAP: Searching %s" % filterstr)
+            lusers = l.search_st(cfg.ldap_base, cfg.ldap_scope, filterstr.encode(coding),
+                                 attrlist=[cfg.ldap_email_attribute,
+                                           cfg.ldap_aliasname_attribute,
+                                           cfg.ldap_surname_attribute,
+                                           cfg.ldap_givenname_attribute,
+                                 ], timeout=cfg.ldap_timeout)
+            # we remove entries with dn == None to get the real result list:
+            lusers = [(dn, ldap_dict) for dn, ldap_dict in lusers if dn is not None]
+            if verbose:
+                for dn, ldap_dict in lusers:
+                    request.log("LDAP: dn:%s" % dn)
+                    for key, val in ldap_dict.items():
+                        request.log("    %s: %s" % (key, val))
+
+            result_length = len(lusers)
+            if result_length != 1:
+                if result_length > 1:
+                    request.log("LDAP: Search found more than one (%d) matches for %s." % (result_length, filterstr))
+                if result_length == 0:
+                    if verbose: request.log("LDAP: Search found no matches for %s." % (filterstr, ))
+                return None, False # if ldap returns unusable results, we veto the user and don't let him in
+
+            dn, ldap_dict = lusers[0]
             if verbose: request.log("LDAP: DN found is %s, trying to bind with pw" % dn)
             l.simple_bind_s(dn, password.encode(coding))
             if verbose: request.log("LDAP: Bound with dn %s (username: %s)" % (dn, username))
-            
+
             email = ldap_dict.get(cfg.ldap_email_attribute, [''])[0]
             email = email.decode(coding)
-            sn, gn = ldap_dict.get('sn', [''])[0], ldap_dict.get('givenName', [''])[0]
+
             aliasname = ''
-            if sn and gn:
-                aliasname = "%s, %s" % (sn, gn)
-            elif sn:
-                aliasname = sn
+            try:
+                aliasname = ldap_dict[cfg.ldap_aliasname_attribute][0]
+            except (KeyError, IndexError):
+                pass
+            if not aliasname:
+                sn = ldap_dict.get(cfg.ldap_surname_attribute, [''])[0]
+                gn = ldap_dict.get(cfg.ldap_givenname_attribute, [''])[0]
+                if sn and gn:
+                    aliasname = "%s, %s" % (sn, gn)
+                elif sn:
+                    aliasname = sn
             aliasname = aliasname.decode(coding)
-            
+
             u = user.User(request, auth_username=username, password=password, auth_method='ldap', auth_attribs=('name', 'password', 'email', 'mailto_author',))
             u.name = username
             u.aliasname = aliasname
             u.email = email
             u.remember_me = 0 # 0 enforces cookie_lifetime config param
             if verbose: request.log("LDAP: creating userprefs with name %s email %s alias %s" % (username, email, aliasname))
-            
+
         except ldap.INVALID_CREDENTIALS, err:
             request.log("LDAP: invalid credentials (wrong password?) for dn %s (username: %s)" % (dn, username))
+            return None, False # if ldap says no, we veto the user and don't let him in
+
+        if u:
+            u.create_or_update(True)
+        return user_obj, True # == nop, moin_cookie has to set the cookie and return the user obj
 
     except:
+        import traceback
         info = sys.exc_info()
         request.log("LDAP: caught an exception, traceback follows...")
         request.log(''.join(traceback.format_exception(*info)))
-
-    if u:
-        u.create_or_update(True)
-    return user_obj, True # moin_cookie has to set the cookie and return the user obj
+        return None, False # something went completely wrong, in doubt we veto the login
 
 
 def interwiki(request, **kw):
