@@ -453,7 +453,7 @@ class strip_whitespace(visitor):
 class convert_tree(visitor):
     white_space = object()
     new_line = object()
-        
+
     def __init__(self, request, pagename):
         self.request = request
         self.pagename = pagename
@@ -542,8 +542,8 @@ class convert_tree(visitor):
             #    self.text.append("\n")
 
     def process_br(self, node):
-            self.text.append(self.new_line) # without this, std multi-line text below some heading misses a whitespace
-                                            # when it gets merged to float text, like word word wordword word word
+        self.text.append(self.new_line) # without this, std multi-line text below some heading misses a whitespace
+                                        # when it gets merged to float text, like word word wordword word word
 
     def process_heading(self, node):
         text = self.node_list_text_only(node.childNodes).strip()
@@ -593,12 +593,11 @@ class convert_tree(visitor):
 
     def process_dl(self, node):
         self.depth += 1
-        markup = ":: " # can there be a dl dd without dt?
         for i in node.childNodes:
             if i.nodeType == Node.ELEMENT_NODE:
                 name = i.localName
+                before, indent, markup = self._get_list_item_markup(node, i)
                 if name == 'dt':
-                    before, indent, markup = self._get_list_item_markup(node, i)
                     self.text.append(before+indent)
                     text = self.node_list_text_only(i.childNodes)
                     self.text.append(text.replace("\n", " "))
@@ -709,6 +708,8 @@ class convert_tree(visitor):
                     self.process_list(i)
                 elif name == 'dl':
                     self.process_dl(i)
+                elif name == 'a':
+                    self.process_a(i)
                 elif name == 'img':
                     self.process_img(i)
                 elif name == 'div':
@@ -762,8 +763,8 @@ class convert_tree(visitor):
             command = ",,"
         elif name == 'sup':
             command = "^"
-        elif name == 'font':
-            command = "" # just throw away font settings
+        elif name in ('font', 'meta', ):
+            command = "" # just throw away unsupported elements
         else:
             raise ConvertError("process_inline: Don't support %s element" % name)
         
@@ -779,17 +780,22 @@ class convert_tree(visitor):
 
     def process_span(self, node):
         # ignore span tags - just descend
+        is_strike = node.getAttribute("class") == "strike"
+        if is_strike:
+            self.text.append("--(")
         for i in node.childNodes:
             self.process_inline(i)
+        if is_strike:
+            self.text.append(")--")
 
     def process_div(self, node):
         # ignore div tags - just descend
         for i in node.childNodes:
-            self.visit_element(i)
+            self.visit(i)
 
     def process_tt(self, node):
         text = self.node_list_text_only(node.childNodes).replace("\n", " ")
-        if node.getAttribute("css") == "backtick":
+        if node.getAttribute("class") == "backtick":
             self.text.append("`%s`" % text)
         else:
             self.text.append("{{{%s}}}" % text)
@@ -902,6 +908,8 @@ class convert_tree(visitor):
                 result.append('rowbgcolor="%s"' % value)
         if node.hasAttribute("style"):
             result.append('rowstyle="%s"' % node.getAttribute("style"))
+        if node.hasAttribute("class"):
+            result.append('rowclass="%s"' % node.getAttribute("class"))
         return " ".join(result).strip()
 
     def _cell_style(self, node):
@@ -955,7 +963,7 @@ class convert_tree(visitor):
             result.append('style="%s"' % node.getAttribute("style"))
                 
         if align:
-            result[0:0] = "%s" % align
+            result.insert(0, "%s" % align)
         result.append(rowspan)
         return " ".join(result).strip()
 
@@ -974,6 +982,8 @@ class convert_tree(visitor):
                 elif name == 'caption':
                     self.process_caption(node, i, style)
                     style = ''
+                elif name  in ('col', 'colgroup', ):
+                    pass # we don't support these, but we just ignore them
                 else:
                     raise ConvertError("process_table: Don't support %s element" % name)
             #else:
@@ -1078,7 +1088,7 @@ class convert_tree(visitor):
             text = self.node_list_text_only(node.childNodes)
             text = text.replace("\n", " ").lstrip()
 
-             # interwiki link
+            # interwiki link
             if class_ == "interwiki":
                 wikitag, wikiurl, wikitail, err = wikiutil.resolve_wiki(
                     self.request, title + ":")
@@ -1088,6 +1098,8 @@ class convert_tree(visitor):
                 else: 
                     raise ConvertError("Invalid InterWiki link: '%s'" % href)
             elif class_ == "badinterwiki" and title:
+                if href == "/": # we used this as replacement for empty href
+                    href = ""
                 pagename = href
                 interwikiname = "%s:%s" % (title, href)
             if interwikiname and pagename == text: 
@@ -1120,13 +1132,13 @@ class convert_tree(visitor):
                 if text == pagename:
                     self.text.append(wikiutil.pagelinkmarkup(pagename))
                 # relative link /SubPage
-                elif href.endswith(text):
+                elif text.startswith('/') and href.endswith(text):
                     if pagename.startswith(self.pagename): # is this a subpage of us?
                         self.text.append(wikiutil.pagelinkmarkup(pagename[len(self.pagename):]))
                     else:
                         self.text.append(wikiutil.pagelinkmarkup(pagename))
                 # relative link ../
-                elif href.endswith(text.lstrip("..").lstrip("/")):
+                elif text.startswith('../') and href.endswith(text[3:]):
                     self.text.append(wikiutil.pagelinkmarkup(text))
                 # labeled link
                 else:
@@ -1199,7 +1211,7 @@ def parse(request, text):
         logname = os.path.join(request.cfg.data_dir, "expaterror.log")
         f = file(logname, "w")
         f.write(text)
-        f.write("\n" + "-"*80 + "\n" + msg)
+        f.write("\n" + "-"*80 + "\n" + str(msg))
         f.close()
         raise ConvertError('ExpatError: %s (see dump in %s)' % (msg, logname))
 
