@@ -6,6 +6,8 @@
     @license: GNU GPL, see COPYING for details.
 """
 
+line_anchors = True
+
 from xml.dom import minidom
 from MoinMoin.formatter.base import FormatterBase
 
@@ -20,23 +22,23 @@ class Formatter(FormatterBase):
         while navigational elements (HTML page header/footer) and the like
         can be printed directly without violating output abstraction.
     """
-
     hardspace = ' '
 
+    # those tags will be automatically reopened if they were auto-closed due to
+    # an enclosing tag being closed:
     format_tags = ['b', 'em', 'highlight', 'sup', 'sub', 'strike', 'code', 'u']
 
-    unbreakables = ['h1', 'h2', 'h3', 'h4', 'h5', 'h6',
-                    'p', 'ol', 'ul', 'li', 'pre', 'a',
-                    'table', 'td', 'tr']
-
+    # those tags want a <p> around them:
     need_p = [] # format_tags[:]
     need_p.extend(['ol', 'a', 'pagelink', 'interwiki', 'macro']) # XXX add more
 
+    # those tags inhibit auto-generation of a <p> after them:
     no_p_after = ['h1', 'h2', 'h3', 'h4', 'h5', 'h6', 'p', 'ol', 'ul', 'pre',
                   'small', 'big', 'table', 'td', 'tr', 'dt',
                   'codearea', 'codeline', 'codetoken',
                   'sysmesg']
 
+    # if key tag is opened, auto-close all tags in value list if they are open
     close_on_open = {
         'h1': ['p'],
         'li': ['li'],
@@ -47,26 +49,22 @@ class Formatter(FormatterBase):
     for i in xrange(2, 7):
         close_on_open['h%i' % i] = close_on_open['h1']
 
-    close_on_open = {} # XXX
-
+    # if key tag is closed, auto-close all tags in value list if they are open
     close_on_close = {
         'table': ['td', 'tr'],
-        'td': ['tr'],
+        'td': ['tr'], # XXX WTF?
         'tr': ['td'],
         'ol': ['li'],
         'ul': ['li'],
         }
-    close_on_close = {} # XXX
+    
+    # FIXME - this overrides the values defined above - FIXME XXX
+    close_on_open = {}
+    close_on_close = {}
 
     def __init__(self, request, **kw):
-        self.request = request
-        self._ = request.getText
+        FormatterBase.__init__(self, request, **kw)
 
-        self._store_pagelinks = kw.get('store_pagelinks', 0)
-        self._highlight_re = None
-        self.pagelinks = []
-        self.in_p = 0
-        self.in_pre = 0
         self.document = minidom.Document()
         self.document.documentElement = self.document.createElement('xml')
         self.position = self.document.documentElement
@@ -81,6 +79,8 @@ class Formatter(FormatterBase):
         @param tag: tag name, string
         @param attrs: attributes keywords, ascii or unicode
         """
+        if tag == 'p':
+            FormatterBase.paragraph(self, 1)
         self.tag_stack.append((tag, attrs))
         node = self.document.createElement(tag)
         for name, value in attrs.items():
@@ -95,9 +95,9 @@ class Formatter(FormatterBase):
             must be the last opened tag!!!
         """
         if tag == 'p':
-            self.in_p = 0 # XXX
+            FormatterBase.paragraph(self, 0)
         if self.tag_stack[-1][0] != tag:
-            raise ValueError, "<%s> expected <%s> given" % (self.tag_stack[-1][0], tag)
+            raise ValueError, "closing of <%s> expected, but <%s> closed" % (self.tag_stack[-1][0], tag)
         self.position = self.position.parentNode
         return self.tag_stack.pop()
 
@@ -123,7 +123,7 @@ class Formatter(FormatterBase):
         if on:
             close_on_open = self.close_on_open.get(tag, [])
             tags_to_reopen = []
-            while 1:
+            while True:
                 last_tag = self.tag_stack[-1][0]
                 if last_tag in close_on_open:
                     self._close_tag(last_tag)
@@ -154,9 +154,9 @@ class Formatter(FormatterBase):
                 elif last_tag in self.format_tags:
                     tags_to_reopen.append(self._close_tag(last_tag))
                 else:
-                    print self.tag_stack
+                    self.request.write("tag_stack: %r\n" % self.tag_stack)
                     self.request.write(self.document.documentElement.toprettyxml(" "))
-                    raise ValueError, "<%s> expected <%s> given" % (last_tag, tag)
+                    raise ValueError, "closing of <%s> expected, but <%s> closed" % (last_tag, tag)
             self._close_tag(tag)
             tags_to_reopen.reverse()
             for tag_name, args in tags_to_reopen:
@@ -171,14 +171,12 @@ class Formatter(FormatterBase):
                 return
         if self.in_p:
             return
-        self.in_p = 1
         self._open_tag('p', type=str(opening_tag))
 
     def sysmsg(self, on, **kw):
         """ Emit a system message (embed it into the page).
 
-            Normally used to indicate disabled options, or invalid
-            markup.
+            Normally used to indicate disabled options, or invalid markup.
         """
         return self._set_tag('sysmesg', on, **kw)
 
@@ -220,8 +218,7 @@ class Formatter(FormatterBase):
                 self.text('\n'.join(lines)) +
                 self._set_tag('processor', False))
 
-    def dynamic_content(self, parser, callback, arg_list=[], arg_dict={},
-                        returns_content=1):
+    def dynamic_content(self, parser, callback, arg_list=[], arg_dict={}, returns_content=1):
         content = parser[callback](*arg_list, **arg_dict)
         if returns_content:
             return content
@@ -234,9 +231,10 @@ class Formatter(FormatterBase):
             kw['class'] = str(css)
         return self._set_tag('a', on, **kw)
 
-    def attachment_link(self, on, url='', **kw):
+    def attachment_link(self, url, text, **kw):
         kw['href'] = url
-        return self._set_tag('attachment', on, **kw)
+        kw['type'] = 'link'
+        return self._set_tag('attachment', 1, **kw) + self.text(text) + self._set_tag('attachment', 0, **kw)
     
     def attachment_image(self, url, **kw):
         kw['href'] = url
@@ -330,6 +328,12 @@ class Formatter(FormatterBase):
     def anchorlink(self, on, name, **kw):
         return self.url(on, "#" + name, **kw)
 
+    def line_anchordef(self, lineno):
+        if line_anchors:
+            return self.anchordef("line-%d" % lineno)
+        else:
+            return ''
+
     def underline(self, on, **kw):
         return self._set_tag('u', on)
 
