@@ -97,7 +97,7 @@ class EditLogLine:
             if not aliasname:
                 aliasname = name
             title = wikiutil.escape(aliasname + title)
-            text = (request.formatter.interwikilink(1, title=title, *info) +
+            text = (request.formatter.interwikilink(1, title=title, generated=True, *info) +
                     request.formatter.text(name) +
                     request.formatter.interwikilink(0, title=title, *info))
         elif kind == 'email':
@@ -155,9 +155,8 @@ class EditLog(LogFile):
                     hostname = host
             else:
                 hostname = host
-            
-            remap_chars = {u'\t': u' ', u'\r': u' ', u'\n': u' ',}
-            comment = comment.translate(remap_chars)
+
+            comment = wikiutil.clean_comment(comment)
             user_id = request.user.valid and request.user.id or ''
 
             if self.uid_override != None:
