@@ -17,6 +17,8 @@ def execute(macro, args):
     # prevent recursion
     if request.mode_getpagelinks: 
         return ''   
+    if request.isSpiderAgent: # reduce bot cpu usage
+        return ''
 
     # Get allpages switch from the form
     allpages = int(request.form.get('allpages', [0])[0]) != 0
@@ -45,7 +47,7 @@ def execute(macro, args):
         # Add links to pages which does not exists in pages dict
         links = page.getPageLinks(request)
         for link in links:
-            if not link in pages:
+            if not link in pages and request.user.may.read(link):
                 if link in wanted:
                     wanted[link][name] = 1
                 else:
