@@ -26,17 +26,21 @@ def _importConfigModule(name):
     @return: module, modification time
     """
     try:
+        # FIXME if someone calls his config module stats.py, it gets confused
+        # with MoinMoin.stats built-in statistics module and fails.
         module = __import__(name, globals(), {})
         mtime = os.path.getmtime(module.__file__)
     except ImportError:
         raise
     except IndentationError, err:
-        msg = 'IndentationError: %s\n' % str(err) + '''
+        msg = '''IndentationError: %(err)s
 
 The configuration files are python modules. Therefore, whitespace is
 important. Make sure that you use only spaces, no tabs are allowed here!
 You have to use four spaces at the beginning of the line mostly.
-'''
+''' % {
+    'err': err,
+}
         raise error.ConfigurationError(msg)
     except Exception, err:
         msg = '%s: %s' % (err.__class__.__name__, str(err))
@@ -95,7 +99,7 @@ def _makeConfig(name):
         cfg = configClass(name)
         cfg.cfg_mtime = max(mtime, _farmconfig_mtime)
     except ImportError, err:
-        msg = 'ImportError: %s\n' % str(err) + '''
+        msg = '''ImportError: %(err)s
 
 Check that the file is in the same directory as the server script. If
 it is not, you must add the path of the directory where the file is
@@ -105,17 +109,29 @@ the top of the server script.
 Check that the configuration file name is either "wikiconfig.py" or the
 module name specified in the wikis list in farmconfig.py. Note that the
 module name does not include the ".py" suffix.
-'''
+''' % {
+    'err': err,
+}
         raise error.ConfigurationError(msg)
-    except AttributeError:
-        msg = '''
-Could not find required "Config" class in "%(name)s.py". This might
-happen if you are trying to use a pre 1.3 configuration file, or made a
-syntax or spelling error.
+    except AttributeError, err:
+        msg = '''AttributeError: %(err)s
+
+Could not find required "Config" class in "%(name)s.py".
+
+This might happen if you are trying to use a pre 1.3 configuration file, or
+made a syntax or spelling error.
+
+Another reason for this could be a name clash. It is not possible to have
+config names like e.g. stats.py - because that colides with MoinMoin/stats/ -
+have a look into your MoinMoin code directory what other names are NOT
+possible.
 
 Please check your configuration file. As an example for correct syntax,
 use the wikiconfig.py file from the distribution.
-''' % {'name': name}
+''' % {
+    'name': name,
+    'err': err,
+}
         raise error.ConfigurationError(msg)
     return cfg
 
@@ -126,15 +142,7 @@ def _getConfigName(url):
         match = regex.match(url)
         if match:
             return name
-    # nothing matched
-    msg = '''
-Could not find a match for url: "%(url)s".
-
-Check your URL regular expressions in the "wikis" list in
-"farmconfig.py". 
-''' % {'url': url}
-    raise error.ConfigurationError(msg)    
-
+    raise error.NoConfigMatchedError
 
 def getConfig(url):
     """ Return cached config instance for url or create new one
@@ -238,6 +246,7 @@ reStructuredText Quick Reference
 """),
     }
     edit_locking = 'warn 10' # None, 'warn <timeout mins>', 'lock <timeout mins>'
+    edit_ticketing = True
     edit_rows = 20
                 
     hacks = {} # { 'feature1': value1, ... }
@@ -262,13 +271,26 @@ reStructuredText Quick Reference
     language_ignore_browser = False # ignore browser settings, use language_default
                                     # or user prefs
 
+    log_reverse_dns_lookups = True  # if we do reverse dns lookups for logging hostnames
+                                    # instead of just IPs
+    log_timing = False              # update <data_dir>/timing.log?
+
     lupy_search = False # disabled until lupy is finished
 
     mail_login = None # or "user pwd" if you need to use SMTP AUTH
     mail_sendmail = None # "/usr/sbin/sendmail -t -i" to not use SMTP, but sendmail
     mail_smarthost = None
     mail_from = None # u'Jrgen Wiki <noreply@jhwiki.org>'
-    
+
+    # some dangerous mimetypes (we don't use "content-disposition: inline" for them when a user
+    # downloads such attachments, because the browser might execute e.g. Javascript contained
+    # in the HTML and steal your moin cookie or do other nasty stuff) 
+    mimetypes_xss_protect = [
+        'text/html',
+        'application/x-shockwave-flash',
+        'application/xhtml+xml',
+    ]
+
     navi_bar = [u'RecentChanges', u'FindPage', u'HelpContents', ]
     nonexist_qm = 0
 
@@ -345,6 +367,8 @@ reStructuredText Quick Reference
     
     theme_default = 'modern'
     theme_force = False
+    traceback_show = 1
+    traceback_log_dir = None
     trail_size = 5
     tz_offset = 0.0 # default time zone offset in hours from UTC
     user_autocreate = False # do we auto-create user profiles
@@ -352,13 +376,15 @@ reStructuredText Quick Reference
 
     # a regex of HTTP_USER_AGENTS that should be excluded from logging
     # and receive a FORBIDDEN for anything except viewing a page
-    ua_spiders = ('archiver|cfetch|crawler|curl|gigabot|google|holmes|htdig|httrack|httpunit|jeeves|larbin|leech|'
-                  'linkbot|linkmap|linkwalk|mercator|mirror|msnbot|nutbot|omniexplorer|puf|robot|scooter|'
-                  'search|sherlock|sitecheck|spider|teleport|voyager|webreaper|wget')
+    ua_spiders = ('archiver|cfetch|crawler|curl|francis|gigabot|googlebot|holmes|htdig|httrack|httpunit|jeeves|larbin|leech|'
+                  'linkbot|linkmap|linkwalk|mercator|mirror|msnbot|msrbot|neomo|nutbot|omniexplorer|puf|robot|scooter|seekbot|'
+                  'sherlock|slurp|sitecheck|spider|onetszukaj|teleport|voyager|webreaper|wget')
 
     # Wiki identity
     sitename = u'Untitled Wiki'
-    url_prefix = '/wiki'
+    url_prefix = '/wiki' # default is local, but may be on a remote site
+    url_prefix_local = None # if None, use same value as url_prefix.
+                            # must be same site as wiki engine (for e.g. JS permissions)
     logo_string = None
     interwikiname = None
     
@@ -463,7 +489,10 @@ reStructuredText Quick Reference
             name = dirname + '_dir'
             if not getattr(self, name, None):
                 setattr(self, name, os.path.join(data_dir, dirname))
-            
+
+        if self.url_prefix_local is None:
+            self.url_prefix_local = self.url_prefix
+
         # Try to decode certain names which allow unicode
         self._decode()
 
@@ -653,7 +682,10 @@ Could not import plugin package "%(path)s/plugin" because of ImportError:
 
 Make sure your data directory path is correct, check permissions, and
 that the data/plugin directory has an __init__.py file.
-''' % {'path': self.data_dir, 'err': str(err)}
+''' % {
+    'path': self.data_dir,
+    'err': str(err),
+}
             raise error.ConfigurationError(msg)
 
     def _fillDicts(self):
