@@ -24,5 +24,5 @@ from MoinMoin.util import pysupport
 modules = pysupport.getPackageModules(__file__)
 ''')
         f.close()
-    return rev+1
+    return 1050301
 
