@@ -81,7 +81,10 @@ class SimpleServer(BaseHTTPServer.HTTPServer):
         self._abort = 1
         try:
             import httplib
-            req = httplib.HTTP('%s:%d' % self.server_address)
+            addr = self.server_address
+            if not addr[0]:
+                addr = ("localhost", addr[1])
+            req = httplib.HTTP('%s:%d' % addr)
             req.connect()
             req.putrequest('DIE', '/')
             req.endheaders()
@@ -381,6 +384,10 @@ class MoinRequestHandler(SimpleHTTPServer.SimpleHTTPRequestHandler):
         """
         shutil.copyfileobj(source, outputfile, length=self.bufferSize)
 
+    def address_string(self):
+        """We don't want to do reverse DNS lookups, just return IP address."""
+        return self.client_address[0]
+
 
 def memoryProfileDecorator(func, profile):
     """ Return a profiled function """
@@ -502,7 +509,7 @@ def run(configClass):
             MoinRequestHandler.serve_moin, config.memoryProfile)
     
     if config.logPath:
-        sys.stderr = file(config.logPath, 'at')
+        sys.stderr = file(config.logPath, 'at', 0)
     registerSignalHandlers(quit)
     httpd = makeServer(config)    
     
