@@ -12,6 +12,11 @@ from MoinMoin.util import pysupport
 
 modules = pysupport.getPackageModules(__file__)
 
+# Check whether we can emit a RSS feed (code stolen from wikitest.py).
+# Currently RSS is broken on plain Python, and works only when installing PyXML.
+import xml
+rss_supported = '_xmlplus' in xml.__file__
+
 
 class ThemeBase:
     """ Base class for themes 
@@ -214,7 +219,7 @@ class ThemeBase:
                 aliasname = name
             title = "%s @ %s" % (aliasname, interwiki[0])
             # link to (interwiki) user homepage
-            homelink = (request.formatter.interwikilink(1, title=title, id="userhome", *interwiki) +
+            homelink = (request.formatter.interwikilink(1, title=title, id="userhome", generated=True, *interwiki) +
                         request.formatter.text(name) +
                         request.formatter.interwikilink(0, title=title, id="userhome", *interwiki))
             userlinks.append(homelink)        
@@ -235,8 +240,7 @@ class ThemeBase:
         return html
 
     # Schemas supported in toolbar links, using [url label] format
-    linkSchemas = [r'http://', r'https://', r'ftp://', 'mailto:', r'irc://', ] + \
-                  [x + ':' for x in config.url_schemas]
+    linkSchemas = [x + ':' for x in config.url_schemas]
 
     def splitNavilink(self, text, localize=1):
         """ Split navibar links into pagename, link to page
@@ -571,7 +575,7 @@ class ThemeBase:
             html.append(link % (self.stylesheetsCharset, media, csshref))
 
         
-        # tribute to the most sucking browser...
+        # tribute to the most sucking browser: IE6
         if self.cfg.hacks.get('ie7', False):
             html.append("""
 <!-- compliance patch for microsoft browsers -->
@@ -580,6 +584,14 @@ class ThemeBase:
 <![endif]-->
 """ % prefix)
 
+        csshref = '%s/%s/css/msie.css' % (prefix, self.name)
+        html.append("""
+<!-- css only for MSIE browsers -->
+<!--[if IE]>
+   %s
+<![endif]-->
+""" % link % (self.stylesheetsCharset, 'all', csshref))
+
         # Add user css url (assuming that user css uses same charset)
         if usercss and usercss.lower() != "none":
             html.append(link % (self.stylesheetsCharset, 'all', usercss))
@@ -631,7 +643,7 @@ class ThemeBase:
                 pagename = page.page_name
                 if self.request.cfg.show_interwiki:
                     pagename = "%s: %s" % (self.request.cfg.interwikiname, pagename)
-                info = "%s  (%s)" % (pagename, info)
+                info = "%s  (%s)" % (wikiutil.escape(pagename), info)
                 html = '<p id="pageinfo" class="info"%(lang)s>%(info)s</p>\n' % {
                     'lang': self.ui_lang_attr(),
                     'info': info
@@ -787,22 +799,17 @@ function actionsMenuInit(title) {
     'search_hint' : _('Search', formatted=False),
     }
         return script
-    
-    def shouldUseRSS(self):
-        """ Return True if rss feature is available, or False
 
-        Currently rss is broken on plain Python, and works only when
-        installing PyXML. Return true if PyXML is installed.
+    def shouldUseRSS(self, page):
+        """ Return True if RSS feature is available and we are on the
+            RecentChanges page, or False.
         """
-        # Stolen from wikitest.py
-        try:
-            import xml
-            return xml.__file__.find('_xmlplus') != -1
-        except ImportError:
-            # This error reported on Python 2.2
+        if not rss_supported:
             return False
-        
-    def rsshref(self):
+        return page.page_name == u'RecentChanges' or \
+           page.page_name == self.request.getText(u'RecentChanges', formatted=False)
+
+    def rsshref(self, page):
         """ Create rss href, used for rss button and head link
         
         @rtype: unicode
@@ -810,8 +817,8 @@ function actionsMenuInit(title) {
         """
         return (u'%s/RecentChanges?action=rss_rc&amp;ddiffs=1&amp;unique=1' 
                 % self.request.getScriptname())
-                           
-    def rsslink(self):
+            
+    def rsslink(self, d):
         """ Create rss link in head, used by FireFox
 
         RSS link for FireFox. This shows an rss link in the bottom of
@@ -821,11 +828,12 @@ function actionsMenuInit(title) {
         @return: html head
         """
         link = u''
-        if self.shouldUseRSS():
+        page = d['page']
+        if self.shouldUseRSS(page):
             link = (u'<link rel="alternate" title="%s Recent Changes" '
                     u'href="%s" type="application/rss+xml">') % (
                         self.cfg.sitename,
-                        self.rsshref() )
+                        self.rsshref(page) )
         return link
        
     def html_head(self, d):
@@ -841,7 +849,7 @@ function actionsMenuInit(title) {
             self.headscript(d), # Should move to separate .js file
             self.guiEditorScript(d),
             self.html_stylesheets(d),
-            self.rsslink(),
+            self.rsslink(d),
             ]
         return '\n'.join(html)
 
@@ -1306,10 +1314,11 @@ var gui_editor_link_text = "%(text)s";
         # Should use user interface language and direction
         html = '<div class="recentchanges"%s>\n' % self.ui_lang_attr()
         html += '<div>\n'
-        if self.shouldUseRSS():
+        page = d['page']
+        if self.shouldUseRSS(page):
             link = [
                 u'<div class="rcrss">',
-                u'<a href="%s">' % self.rsshref(),
+                u'<a href="%s">' % self.rsshref(page),
                 self.make_icon("rss"),
                 u'</a>',
                 u'</div>',
