@@ -197,9 +197,9 @@ class User:
         @param request: the request object
         @param id: (optional) user ID
         @param name: (optional) user name
-        @param password: (optional) user password
+        @param password: (optional) user password (unicode)
         @param auth_username: (optional) already authenticated user name
-                              (e.g. when using http basic auth)
+                              (e.g. when using http basic auth) (unicode)
         @keyword auth_method: method that was used for authentication,
                               default: 'internal'
         @keyword auth_attribs: tuple of user object attribute names that are
@@ -279,7 +279,7 @@ class User:
         if self._cfg.SecurityPolicy:
             self.may = self._cfg.SecurityPolicy(self)
         else:
-            from security import Default
+            from MoinMoin.security import Default
             self.may = Default(self)
         
         from MoinMoin.i18n.meta import languages
@@ -520,11 +520,6 @@ class User:
                 data.write(line)
         data.close()
 
-        try:
-            os.chmod(self.__filename(), 0666 & config.umask)
-        except OSError:
-            pass
-
         if not self.disabled:
             self.valid = 1
 
@@ -575,10 +570,6 @@ class User:
             bmfile = open(bm_fn, "w")
             bmfile.write(str(tm)+"\n")
             bmfile.close()
-            try:
-                os.chmod(bm_fn, 0666 & config.umask)
-            except OSError:
-                pass
 
     def getBookmark(self):
         """ Get bookmark timestamp.
@@ -866,12 +857,6 @@ class User:
                 file.write(data)
             finally:
                 file.close()
-
-            try:
-                os.chmod(path, 0666 & config.umask)
-            except OSError, err:
-                self._request.log("Can't change mode of trail file: %s" %
-                                  str(err))
         except (IOError, OSError), err:
             self._request.log("Can't save trail file: %s" % str(err))
 
