@@ -74,10 +74,9 @@ def getblacklist(request, pagename, do_update):
     """
     from MoinMoin.PageEditor import PageEditor
     p = PageEditor(request, pagename, uid_override="Antispam subsystem")
-    invalidate_cache = False
+    mymtime = wikiutil.version2timestamp(p.mtime_usecs())
     if do_update:
-        tooold = time.time() - 3600
-        mymtime = wikiutil.version2timestamp(p.mtime_usecs())
+        tooold = time.time() - 1800
         failure = caching.CacheEntry(request, "antispam", "failure")
         fail_time = failure.mtime() # only update if no failure in last hour
         if (mymtime < tooold) and (fail_time < tooold):
@@ -127,8 +126,11 @@ def getblacklist(request, pagename, do_update):
                         raise WikirpcError("failed to get BadContent data",
                                            response)
                     p._write_file(response)
-
-                invalidate_cache = True
+                    mymtime = wikiutil.version2timestamp(p.mtime_usecs())
+                else:
+                    failure.update("") # we didn't get a modified version, this avoids
+                                       # permanent polling for every save when there
+                                       # is no updated master page
 
             except (socket.error, xmlrpclib.ProtocolError), err:
                 # Log the error
@@ -138,6 +140,13 @@ def getblacklist(request, pagename, do_update):
                 # update cache to wait before the next try
                 failure.update("")
 
+            except (xmlrpclib.Fault, ), err:
+                # Log the error
+                # TODO: check if this does not fill the logs!
+                dprint('Fault on moinmaster: %s' % str(err))
+                # update cache to wait before the next try
+                failure.update("")
+
             except Error, err:
                 # In case of Error, we log the error and use the local
                 # BadContent copy.
@@ -147,7 +156,7 @@ def getblacklist(request, pagename, do_update):
             socket.setdefaulttimeout(old_timeout)
                 
     blacklist = p.get_raw_body()
-    return invalidate_cache, makelist(blacklist)
+    return mymtime, makelist(blacklist)
 
 
 class SecurityPolicy(Permissions):
@@ -162,23 +171,23 @@ class SecurityPolicy(Permissions):
             request.clock.start('antispam')
             
             blacklist = []
-            invalidate_cache = not getattr(request.cfg, "_mmblcache", None)
+            latest_mtime = 0
             for pn in BLACKLISTPAGES:
                 do_update = (pn != "LocalBadContent")
-                invalidate_cache_necessary, blacklist_entries = getblacklist(request, pn, do_update)
+                blacklist_mtime, blacklist_entries = getblacklist(request, pn, do_update)
                 blacklist += blacklist_entries
-                invalidate_cache |= invalidate_cache_necessary
+                latest_mtime = max(latest_mtime, blacklist_mtime)
 
             if blacklist:
-                if invalidate_cache:
+                invalid_cache = not getattr(request.cfg, "_mmblcache", None)
+                if invalid_cache or request.cfg._mmblcache[0] < latest_mtime:
                     mmblcache = []
                     for blacklist_re in blacklist:
                         try:
                             mmblcache.append(re.compile(blacklist_re, re.I))
                         except re.error, err:
                             dprint("Error in regex '%s': %s. Please check the pages %s." % (blacklist_re, str(err), ', '.join(BLACKLISTPAGES)))
-                            continue
-                    request.cfg._mmblcache = mmblcache
+                    request.cfg._mmblcache = (latest_mtime, mmblcache)
 
                 from MoinMoin.Page import Page
 
@@ -192,7 +201,7 @@ class SecurityPolicy(Permissions):
                 difference = newset.difference(oldset)
                 addedtext = ''.join(difference) 
                 
-                for blacklist_re in request.cfg._mmblcache:
+                for blacklist_re in request.cfg._mmblcache[1]:
                     match = blacklist_re.search(addedtext)
                     if match:
                         # Log error and raise SaveError, PageEditor
