@@ -146,7 +146,7 @@ class AccessControlList:
         @param aclstring: acl string from page or cfg
         @param remember: should add the line to self.acl_lines
         """
-        group_re = re.compile(cfg.page_group_regex)
+        group_re = re.compile(cfg.page_group_regex, re.U)
 
         # Remember lines
         if remember:
