@@ -521,6 +521,13 @@ def do_revert(pagename, request):
 
 def do_edit(pagename, request):
     _ = request.getText
+    form = request.form
+    if form.has_key('button_preview') and form.has_key('button_spellcheck'):
+        # multiple buttons pressed at once? must be some spammer/bot
+        request.makeForbidden403()
+        request.surge_protect(kick_him=True) # get rid of him
+        request.log("LOL, some spammer pressed multiple buttons at once ...")
+        return
 
     if not request.user.may.write(pagename):
         Page(request, pagename).send_page(request,
@@ -574,10 +581,17 @@ def do_edit(pagename, request):
     if savetext is None:
         pg.sendEditor()
         return
-  
+
     # did user hit cancel button?
     cancelled = request.form.has_key('button_cancel')
 
+    if request.cfg.edit_ticketing:
+        ticket = request.form.get('ticket', [''])[0]
+        if not wikiutil.checkTicket(request, ticket):
+            msg = _('Please use the interactive user interface to use action %(actionname)s!') % {'actionname': 'edit' }
+            pg.send_page(request, msg=msg)
+            return
+
     # convert input from Graphical editor
     from MoinMoin.converter.text_html_text_x_moin import convert, ConvertError
     try:
