@@ -1,4 +1,4 @@
-# -*- coding: iso8859-1 -*-
+# -*- coding: iso-8859-1 -*-
 """
     MoinMoin - Wiki XMLRPC v1 and v2 Interface
 
@@ -24,12 +24,13 @@
     @license: GNU GPL, see COPYING for details
 """
 
-import sys, urllib, time, xmlrpclib
+import sys, time, xmlrpclib
 
 from MoinMoin import config, user, wikiutil
 from MoinMoin.Page import Page
 from MoinMoin.PageEditor import PageEditor
 from MoinMoin.logfile import editlog
+from MoinMoin.formatter import text_html
 
 _debug = 0
 
@@ -213,7 +214,7 @@ class XmlRpcBase:
 
         # Get page info
         last_edit = page.last_edit(self.request)           
-        mtime = wikiutil.version2timestamp(int(last_edit['timestamp']))
+        mtime = wikiutil.version2timestamp(long(last_edit['timestamp'])) # must be long for py 2.2.x
         gmtuple = tuple(time.gmtime(mtime))
         
         version = rev # our new rev numbers: 1,2,3,4,....
@@ -230,7 +231,7 @@ class XmlRpcBase:
         #######################################################################
             
         return {
-            'name': pagename,
+            'name': self._outstr(page.page_name),
             'lastModified' : xmlrpclib.DateTime(gmtuple),
             'author': self._outstr(last_edit['editor']),
             'version': version,
@@ -297,14 +298,9 @@ class XmlRpcBase:
             return self.noSuchPageFault()
         
         # Render page into a buffer
-        import StringIO
-        out = StringIO.StringIO()
-        self.request.redirect(out)
-        self.request.form = self.request.args = self.request.setup_args({})
-        page.send_page(self.request, content_only=1)
-        result = out.getvalue()
-        self.request.redirect()
-
+        result = self.request.redirectedOutput(page.send_page, self.request,
+                                               content_only=1)
+        
         # Return rendered page
         if self.version == 2:
             return self._outstr(result)
@@ -384,25 +380,25 @@ class XmlRpcBase:
         if _debug and msg:
             sys.stderr.write("Msg: %s\n" % msg)
 
-        #we need this to update pagelinks cache:
-        import StringIO
-        out = StringIO.StringIO()
-        self.request.redirect(out)
-        self.request.args = self.request.form = self.request.setup_args({})
-        page.send_page(self.request, content_only=1)
-        self.request.redirect()
+        # Update pagelinks cache
+        page.getPageLinks(self.request)
 
         return xmlrpclib.Boolean(1)
 
+    def xmlrpc_searchPages(self, query_string):
+        from MoinMoin import search
+        query = search.QueryParser().parse_query(query_string)
+        results = search.searchPages(self.request, query)
+        results.formatter = text_html.Formatter(self.request)
+        results.request = self.request
+        return [(self._outstr(hit.page_name),
+                 self._outstr(results.formatContext(hit, 180, 1)))
+                for hit in results.hits]
+
     def process(self):
         """ xmlrpc v1 and v2 dispatcher """
         try:
-            try:
-                #print self.request.env
-                length = int(self.request.env['content-length'])
-            except:
-                length = None
-            data = self.request.read(length)
+            data = self.request.read()
             params, method = xmlrpclib.loads(data)
     
             if _debug:
@@ -411,11 +407,17 @@ class XmlRpcBase:
             
             try:
                 fn = getattr(self, 'xmlrpc_' + method)
-                response = fn(*params)
             except AttributeError:
-                fn = wikiutil.importPlugin(self.request.cfg, 'xmlrpc', method,
-                                           'execute')
-                response = fn(self, *params)
+                try:
+                    fn = wikiutil.importPlugin(self.request.cfg, 'xmlrpc',
+                                               method, 'execute')
+                except wikiutil.PluginMissingError:
+                    response = xmlrpclib.Fault(1, "No such method: %s." %
+                                               method)
+                else:
+                    response = fn(self, *params)
+            else:
+                response = fn(*params)
         except:
             # report exception back to server
             response = xmlrpclib.dumps(xmlrpclib.Fault(1, self._dump_exc()))
@@ -458,11 +460,7 @@ class XmlRpc1(XmlRpcBase):
         @rtype: unicode
         @return: text
         """
-        if isinstance(text, unicode):
-            text = text.encode('utf-8') # ascii should also work
-        text = urllib.unquote(text)
-        text = unicode(text, 'utf-8')
-        return text
+        return wikiutil.url_unquote(text) # config.charset must be utf-8
 
     def _outstr(self, text):
         """ Convert string from internal representation to xmlrpc
@@ -471,12 +469,7 @@ class XmlRpc1(XmlRpcBase):
         @rtype: str
         @return: text encoded in utf-8 and quoted
         """
-        if isinstance(text, unicode):
-            text = text.encode('utf-8')
-        elif config.charset != 'utf-8':        
-            text = unicode(text, config.charset).encode('utf-8')
-        text = urllib.quote(text)
-        return text
+        return wikiutil.url_quote(text) # config.charset must be utf-8
 
     
 class XmlRpc2(XmlRpcBase):
